package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(W``````````0```````
M`,&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*XP````````KC``
M```````0``````$````&````````N[````````"[L````````+NP````````
M!-@````````%`````````!```````@````8```````"[P````````+O`````
M````N\`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````IE@```````"F6````````*98`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+NP````````N[``````
M``"[L`````````10````````!%```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`Z6HT0+Y'QPQ+QZ*#FJ0FWH(`9Q@````$````$```
M``%'3E4```````````,````"```````````````1````1`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````1````$<```!*
M````2P```%,```!4````50````````!7````6````%D```!:````6P```%T`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&9```````````````WL2````````````````
M`````````````J82`````````````````````````````(P1````````````
M`````````````````<,2`````````````````````````````@T2````````
M`````````````````````HT2`````````````````````````````+T2````
M`````````````````````````DD2`````````````````````````````<H2
M``````````````````````````````$@````````````````````````````
M`H82`````````````````````````````&<2````````````````````````
M`````;82`````````````````````````````,82````````````````````
M`````````M@2`````````````````````````````842````````````````
M`````````````?T2`````````````````````````````2D2````````````
M`````````````````6H2`````````````````````````````)02````````
M`````````````````````!`@`````````````````````````````KX2````
M`````````````````````````2`2`````````````````````````````(H1
M`````````````````````````````3<2````````````````````````````
M`"P@`````````````````````````````)T2````````````````````````
M`````K`2`````````````````````````````4T2````````````````````
M`````````.$6`````````````````````````````/02````````````````
M`````````````7X2`````````````````````````````EP2````````````
M`````````````````0\2`````````````````````````````LD2````````
M`````````````````````+,2`````````````````````````````%@B````
M`````````````````````````=<2`````````````````````````````;$2
M`````````````````````````````3X2````````````````````````````
M`=$2`````````````````````````````6,2````````````````````````
M`````:(2`````````````````````````````I@2````````````````````
M`````````BX2`````````````````````````````'D2````````````````
M`````````````7<2`````````````````````````````>@2````````````
M`````````````````)P2`````````````````````````````-H2````````
M`````````````````````AD2`````````````````````````````;X2````
M`````````````````````````GH2`````````````````````````````JL2
M`````````````````````````````?82````````````````````````````
M`FT1`````````````````````````````8P2````````````````````````
M`````*02`````````````````````````````,P2````````````````````
M`````````002`````````````````````````````542````````````````
M`````````````*L2`````````````````````````````CH2````````````
M`````````````````$82`````````````````````````````902````````
M`````````````````````9L1`````````````````````````````X02```-
M````````82``````````W````]D2```-````````5=`````````(^@```%,2
M```-````````(-`````````"E````OL2```-````````11``````````$@``
M`QD2```-````````7M`````````"3````_\2```-````````13`````````#
MU````[\0```7````````P(@``````````````PP2```-````````21``````
M````0@```R\2```-````````4+``````````A````Y`1```/````````99``
M````````!````ZP2```-````````8G`````````!2@```[<2```-````````
M0[``````````1````]00```7````````P+```````````````^T2```-````
M````5!`````````!M@``!!82```-````````44``````````A@```Y\0```6
M````````P````````````````U,2```-````````26`````````!J````^80
M```7````````P(@`````````````!`P1```6````````P(``````````"```
M`Z42```-````````(W```````````````\L2```-````````8@``````````
M8@```Z$@```6````````P````````````````VD2```-````````4]``````
M````.@```ST2```-````````1``````````!#````U\2```-````````8\``
M```````!A```!!X2```-````````2Q`````````%F@!?7V=M;VY?<W1A<G1?
M7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?
M7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV:7)O;@!S
M=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`&-L;W-E
M9&ER`')M9&ER`%]?<W!R:6YT9E]C:&L`=6YL:6YK`%!,7V-U<G)E;G1?8V]N
M=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L
M86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T
M<'9N`')E86QL;V,`7U]M96UM;W9E7V-H:P!G971P:60`7U]M96UC<'E?8VAK
M`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M8W!Y`'-T9&5R<@!?
M7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G971U:60`<W1R<W1R
M`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`
M4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]P87)S90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!0
M97)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R
M=6X`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`````````
M`@`!``(``@`!``$``@`!``(``0`"``,``@`"``$``@`!``$`!``"``$``0`"
M``(``@`!``4``0`"``$``0`"``$``0`!``(``@`"``(``0`"``(`!@`!``$`
M!@`"``8`!0`"``$``@`!``(``@`!``(``@`&``$`!``"``$`!P`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``````````$`!@```O$````0``````:6D;0````'```$*P```!`-:6D4
M````!@``!#8````0!I:1LP````4```1`````$`EI&70````$```$2P```!`)
M:1ER`````P``!%<````0#6EI$@````(```1C`````````````+NP````````
M``P````````DD````````+NX``````````P````````D0````````+^H````
M``````P```````!>T````````+_H``````````P```````#`@````````+_X
M``````````P````````@T````````,`(``````````P```````#`"```````
M`,`@``````````P```````"E_@```````,`H``````````P```````!E[```
M`````,`X``````````P```````!FC````````,!```````````P```````!F
MD````````,!(``````````P```````"E\@```````,!0``````````P`````
M``!E\@```````,!8``````````P```````"E^@```````,!H``````````P`
M``````"EX@```````,!P``````````P```````"EZ````````,"`````````
M``P```````!H<@```````+^0````!`````H``````````````````+^8````
M"0````H``````````````````+^@````"P````H``````````````````+^P
M````%@````H``````````````````+^X````&P````H`````````````````
M`+_`````'P```#@``````````````````+_(````(`````H`````````````
M`````+_0````(@````H``````````````````+_8````)@````H`````````
M`````````+_@````.0````H``````````````````+_P````0P````H`````
M`````````````+W8`````@````L``````````````````+W@`````P````L`
M`````````````````+WH````!0````L``````````````````+WP````!@``
M``L``````````````````+WX````!P````L``````````````````+X`````
M"`````L``````````````````+X(````"@````L``````````````````+X0
M````#`````L``````````````````+X8````#0````L`````````````````
M`+X@````#@````L``````````````````+XH````#P````L`````````````
M`````+XP````$`````L``````````````````+XX````$0````L`````````
M`````````+Y`````$@````L``````````````````+Y(````$P````L`````
M`````````````+Y0````%`````L``````````````````+Y8````%0````L`
M`````````````````+Y@````%P````L``````````````````+YH````&```
M``L``````````````````+YP````&@````L``````````````````+YX````
M'`````L``````````````````+Z`````'0````L``````````````````+Z(
M````'@````L``````````````````+Z0````(0````L`````````````````
M`+Z8````(P````L``````````````````+Z@````)`````L`````````````
M`````+ZH````)0````L``````````````````+ZP````)@````L`````````
M`````````+ZX````)P````L``````````````````+[`````*`````L`````
M`````````````+[(````*0````L``````````````````+[0````*@````L`
M`````````````````+[8````*P````L``````````````````+[@````+```
M``L``````````````````+[H````+0````L``````````````````+[P````
M+@````L``````````````````+[X````+P````L``````````````````+\`
M````,`````L``````````````````+\(````,0````L`````````````````
M`+\0````,@````L``````````````````+\8````,P````L`````````````
M`````+\@````-`````L``````````````````+\H````-0````L`````````
M`````````+\P````-@````L``````````````````+\X````-P````L`````
M`````````````+]`````.`````L``````````````````+](````.@````L`
M`````````````````+]0````.P````L``````````````````+]8````/```
M``L``````````````````+]@````/0````L``````````````````+]H````
M/@````L``````````````````+]P````/P````L``````````````````+]X
M````0`````L``````````````````+^`````00````L`````````````````
M`+^(````0@````L``````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```%(.
MP!```%+[XQ`0```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T!P?C$/`X`"3`
M$```4?72!_`P$`CC$!`0``0'\0<`!P`'`,`0``!1].,0$```!`?Q#1#C$!`,
M`!3`]/___^4`````P!```%'HXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`
M$```4=SC$!````0'\0T0XQ`0#``4P/3____%````,,`0``!1T.,0$```!`?Q
M#1#C$!`,`!3`]/___[4```!(P!```%'$XQ`0```$!_$-$.,0$`P`%,#T____
MI0```&#`$```4;CC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!1K.,0
M$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%&@XQ`0```$!_$-$.,0$`P`
M%,#T____=0```*C`$```493C$!````0'\0T0XQ`0#``4P/3___]E````P,`0
M``!1B.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%%\XQ`0```$!_$-
M$.,0$`P`%,#T____10```/#`$```47#C$!````0'\0T0XQ`0#``4P/3___\U
M```!",`0``!19.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```%%8XQ`0
M```$!_$-$.,0$`P`%,#T____%0```3C`$```44SC$!````0'\0T0XQ`0#``4
MP/3___\%```!4,`0``!10.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!``
M`%$TXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```42CC$!````0'\0T0
MXQ`0#``4P/3___[5```!F,`0``!1'.,0$```!`?Q#1#C$!`,`!3`]/___L4`
M``&PP!```%$0XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```403C$!``
M``0'\0T0XQ`0#``4P/3___ZE```!X,`0``!0^.,0$```!`?Q#1#C$!`,`!3`
M]/___I4```'XP!```%#LXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```
M4.#C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!0U.,0$```!`?Q#1#C
M$!`,`!3`]/___F4```)`P!```%#(XQ`0```$!_$-$.,0$`P`%,#T___^50``
M`EC`$```4+SC$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!0L.,0$```
M!`?Q#1#C$!`,`!3`]/___C4```*(P!```%"DXQ`0```$!_$-$.,0$`P`%,#T
M___^)0```J#`$```4)CC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!0
MC.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%"`XQ`0```$!_$-$.,0
M$`P`%,#T___]]0```NC`$```4'3C$!````0'\0T0XQ`0#``4P/3___WE```#
M`,`0``!0:.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```%!<XQ`0```$
M!_$-$.,0$`P`%,#T___]Q0```S#`$```4%#C$!````0'\0T0XQ`0#``4P/3_
M__VU```#2,`0``!01.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```%`X
MXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```4"SC$!````0'\0T0XQ`0
M#``4P/3___V%```#D,`0``!0(.,0$```!`?Q#1#C$!`,`!3`]/___74```.H
MP!```%`4XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```4`CC$!````0'
M\0T0XQ`0#``4P/3___U5```#V,`0``!/_.,0$```!`?Q#1#C$!`,`!3`]/__
M_44```/PP!```$_PXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```3^3C
M$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!/V.,0$```!`?Q#1#C$!`,
M`!3`]/___14```0XP!```$_,XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`
M$```3\#C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!/M.,0$```!`?Q
M#1#C$!`,`!3`]/___.4```2`P!```$^HXQ`0```$!_$-$.,0$`P`%,#T___\
MU0``!)C`$```3YSC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!/D.,0
M$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$^$XQ`0```$!_$-$.,0$`P`
M%,#T___\I0``!.#`$```3WCC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0
M``!/;.,0$```!`?Q#1#C$!`,`!3`]/___(4```40ZV_P,``DLD\`H+D$`._K
MJ@`@``WC\/\X_W'CX/```"2R3P"AN00`O^,PL*@`).-`L*``)%`@L+32![#`
MH"A!0+"@03"PJ$$@L+3`Y?___ZO$2```3SS$*```3U6Y!``TP.4``"(0Q!@`
M`$]5E0`0`*>$`+G`,```3S[C4#````18D+"TXV6@```$[(D`!`#8E@-DBKD4
M`.CK+@`#``VGF@`#P.7___[OXQ"PJ``$P#```$^!XP`0```$XV`P```$XP`@
M```D6("PM+D$`%+C8%`0`"3$*P``3WK`0```(V+C0%`8`"3`(```(UKC(%`(
M`"3LC`#%`7[L2``#`-CL"/__`-A!X!`(IR@`!*<!``&G=`""B````;D4`&+K
M1@`#``WC8.````3L$@`!`-CC9%```"2Y%``QZQ,``P`-XS#@"``$IRH``N,Q
M4```)*?K`!"G!O_C[.@``P#8Q"@``$\^N10`CKD4`$GKF``#``U!Z5``Y4C@
M````IVD``,`P```.,<#E___\#NPH`%0`?L0H``!/)$%@L+S`Y?___>.Y!``V
MN00`@L`@```AX\#E```,2>PH`$<`?,0H``!/#\#E___[P,#E___\_=4'L,"@
M**=T`%FY!``HZV^P^``$!_[`Y?___*_$*P``3OCL*`!.`'S`Y?___2;`,```
M3GOC(#````3C0J````22`$E^I_3_->,PX```!*<H``7C,%`@`"1!X!`0["3_
M=F!VI_3_E,0H``!.T\#E___\)*?T_ZG`4```3L?C(%````*GA``'P.4``![_
MI_3_L;D$`#;`(```(5_`Y0``"^W$*P``3K+L*/^D`'RG]/_MI^@`!*?T_V[`
MY?___8ZG*0`!P.7___T9!P<'!P<'!P<'!P<'04#P".,P\```!*<)__"Y@`#P
MI_O_4-<'\`#P`.OO\*``)$%P\*"G:0``IUD``,`@``!.+>,@(```!,#E___^
M<P``!P<'!P<'!P<'!P<'!P?`$```3F3`(```3F'L$@`*@&3$&```3>_L&``$
M`'P'\0?^!P<'!P<'!P<'!P<'!P?`$```3DS`(```3DFY"0`2ZP$``P`*ZS$`
M/P`,N0@`,.LS``$`"NPX``T`?,08``!-SNP8``<`?,`@``!.,`?Q!_X'!P<'
M!P<'!P<'!P<'!^N_\%@`),"P``!.(>/P_V#_<94`L`"G=``5P!```$V_XQ`0
M```"IX0`",0H``!-S\#E___\<,#E____I9(!L`#KO_#X``0'_@<'!P<'!P<'
MP/3___^P!P<'!P<'!P<'!^MO\#``)+)/`!"Y!`#OZS$`(``-LD\`,>/P_,C_
M<>/@\```)+D$`+_C,+"@`"3G8`\/`$1!H+"PT@>S,#`HN00`:D%0(#BY!`!Z
MITD`!.<`4``P!J=;`!#G(``@,#CG$&```&CG0A``,&'G,A``,&#G0'``,`[G
M,'`0,`ZG>P`@IT?_Y^?`H!`X!N?@H"`X!N<@H#`X!N=0#P\`1*<)`"#G`&!H
M.`;G<@``!%;G(&!`.`;G0&``.`:G:P`0YV(```YMYQ9```YMYS'```YMYU,`
M`3PPYW,`'SPXYX5P``YJYZA0``QHYZ!@<#@.Y\X```Q6Y^<```A6IP?_U./@
M(`@`!..@(!``!.-`(!@`!.-0(```!.-`L*@`)./0L+@`!.,PL+``!+GG0`JY
M@``.N8(`!,+:6H)YF>QU(+\E6;D(`-3L=2`Z!5;".EJ">9GC0+#```3C,"`@
M``BY"`!SN0@`<.,`L,@`!.N.``(`#,(*6H)YF>R.`"$>5L)*6H)YF;D(`$KL
MF""_`%7K-0`"``SL-0`A'E:YYS!H[(<@OP!5N8``:+F"`&FY"`!DN>B00.,`
ML-``!+GGD!K""EJ">9FY@``5N8(`&KD(`!WLUSN_)5GLV``Z!5:Y"``=['$@
MOP!5[!$[OR59[!<`.@56N0@`%NN8``(`#.QC(+\`5>R8`"$>5NS1.[\E6>R!
M(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"PV``$N00`/<(*6H)YF>PX`#H%
M5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3Y]`/#PA$
MN>2`&;F"`!:Y"``4N>A@0.,`L.``!+D$`)W""EJ">9GLEP`Z!5:Y"``9[&,@
MOP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`%+GH
M8$#C`+#H``2Y!``]P@I:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E6>LW``(`
M#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!2YZ&!`XP"P\``$N00`G<(*
M6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L@2"_`%6Y
M@@`YN>1P$[F"`!:Y"``4N>A@0.,`L/@`!+D$`#W""EJ">9GL.``Z!5:Y"``3
M[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY@@`6N0@`
M%+GH8$#C`+$```2Y!`"=P@I:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8
M``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"Q"``$N00`
M/<(*6H)YF>PX`#H%5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_
M`%6Y@@"3N>2`&;F"`!:Y"``4N>A@0.,`L1``!+D$`)W""EJ">9GLEP`Z!5:Y
M"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6
MN0@`%+GH8$#C`+$8``2Y!``]P@I:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E
M6>LW``(`#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!2YZ&!`XP"Q(``$
MN00`G<(*6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L
M@2"_`%6Y@@`YN>1P$[F"`!:Y"``4N>A@0.,`L2@`!+D$`#W""EJ">9GL.``Z
M!5:Y"``3[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY
M@@`6N0@`%+GH8$#C`+$P``2Y!`"=P@I:@GF9[)<`.@56N0@`&>QC(+\`5>S1
M.[\E6>N8``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"Q
M.``$N00`/>PX`#H%5NQI(+\`5;D(`!/""EJ">9GK-P`"``SL-P`A'E:Y@@"3
M['$@OP!5[-$[OR59N>2`&;D$`)VY@@`6[)<`.@56N0@`%+GH8$#C`+%```2Y
M"``9[&,@OP!5ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5>S1.[\E6<(*6H)YF;GD
M<!.Y!``]N8(`%NPX`#H%5KD(`!2YZ&!`N0@`$^QI(+\`5>LW``(`#.PW`"$>
M5N-PL4@`!+F"`).Y@`"8N8(`EKD(`)3K2``"``SL2``A'E;C@+%0``3">EJ"
M>9G"BF[9ZZ&YZ&`'[-$[OR59[-$@.@56P!H`````N0@`G>QS(+\`5;F"`#2Y
M@``QN8(`-[D(`'BY"``PXP"Q6``$ZX$``@`,[($`(1Y6N>>`%+F"`!GL:3N_
M)5FY&@!Q[&D@.@56XQ"Q8``$N0@`-L(*;MGKH>S3.[\E6;D$`&#LTR`Z!5:Y
M&@!DN0@`?>Q)(K\^6>S7.[\E6>Q)`B$>5NS7(#H%5KGG0`C"&F[9ZZ&Y@@`#
MN1H`&+D$`);C@+%H``3L8R*_/EGL8P(A'E:YYV`TN8(`-[D:`)"Y&@`3N0@`
MG>,PL7``!.S9.[\E6>S9(#H%5L**;MGKH;D(`!VY&@"$[-<BOSY9[$DBOSY9
M[-<"(1Y6[$D"(1Y6N>?0=KF"`'FYYT"=N8(`D>P!.[\E6<(Z;MGKH>P!(#H%
M5KD:`#:Y&@`YXY"Q>``$N1H`A^QA(K\^6;D(`(#L80(A'E;L"#N_)5GC$+&`
M``3L""`Z!5:Y"``PPIINV>NAN>=@=,(:;MGKH;F"`'BY&@`4[$@BOSY9[$@"
M(1Y6XX"QB``$N1H`G<**;MGKH;D:`)>Y&@"&N>=`=NS3.[\E6;F"`'/LTR`Z
M!5:Y&@`7N0@`G>QC(K\^6>P).[\E6>QC`B$>5NP)(#H%5KD(`!#L,3N_)5GL
M,2`Z!5:SP0!SXS"QD``$N>=@!,(Z;MGKH;F"``FY&@`T['DBOSY9L\T`1^QY
M`B$>5N.0L9@`!+D:`(#"FF[9ZZ&Y"`"$N>=P!KD:`):Y@@`![-@[OR59N1H`
M,.S8(#H%5NQA(K\^6;D(`#WL80(A'E;L$SN_)5GL$R`Z!5:YYV#7XT"QH``$
MN8(`V+D:`)VY"`"1[!@BOSY9[!@"(1Y6XX"QJ``$N><0UL)*;MGKH;F"`-.Y
M&@!'[`D[OR59N1H`3>P)(#H%5L**;MGKH;D(`$"Y&@"&[&,BOSY9[&,"(1Y6
M[#0[OR59[#0@.@56L\$`$^,PL;``!+GG8`'".F[9ZZ&Y@@`)N1H`,>QY(K\^
M6;/-`!'L>0(A'E;CD+&X``2Y&@"`PIINV>NAN0@`@;GG<`:Y&@"6[-@[OR59
M[-@@.@56L\$`3;/-`&2Y@@`$[-0BOSY9N1H`,.S4`B$>5KD(`#:YY]`'[$,[
MOR59N8(`".Q#(#H%5KD:`)"Y"`"4[&D[OR59[&D@.@56XQ"QP``$L\$`5N-@
ML<@`!+/-``7"&F[9ZZ'L2"*_/EFY&@`7[$@"(1Y6PFINV>NAN>=`C;D:`&VY
M@@"#[-,BOSY9N1H`&.S3`B$>5KD(`!#L,3N_)5GL,2`Z!5:SP0!SXS"QT``$
MN>?0=,(Z;MGKH;D:`#2SS0!'N8(`>>R)(K\^6;D:`&?LB0(A'E:Y"`!DN>>`
MG>P&.[\E6;F"`)'L!B`Z!5:Y&@`Y[$$BOSY9N0@`,.Q!`B$>5NP3.[\E6>P3
M(#H%5K/!``'C$+'@``2YYT`(PAINV>NAXW"QV``$N1H`&+/-`("Y@@`&PGIN
MV>NAN1H`?;D:`'"Y"`!X[(<@OP!5[)<[OR59[)@`.@56[-8BOSY9XP"Q\``$
M[-8"(1Y6N>?09+F"`&.Y&@`6N0@`&>.0L>@`!.QC(K\^6<*:;MGKH>QC`B$>
M5KD:`)2YYV`][$$[OR59N8(`-\(*CQN\W.QQ(+\`5;D:``WK&``"``SL&``A
M'E;LT2"_`%6YY-"&[$<`.@56N1H`D[GF$#:Y@``WN8$`...`L?@`!+D(`)2Y
M"``P[$D@OP!5XP"R```$[)D[OR59[)0`.@56PHJ/&[S<N0@`.;D:`(;KEP`"
M``SLEP`A'E:YY-!YN8$`&;F``!2Y@0`7N0@`&.QC(+\`5<(*CQN\W.PS.[\E
M6;D(``WL-@`Z!5:Y"``QZQ0``@`,[!0`(1Y6[-$@OP!5N>30B;GF$$FY@`!&
MN8$`2.R#(+\`5;D(`$#L,SN_)5GC`+((``3L.``Z!5:Y"``T[',@OP!5[$,[
MOR59XS"R$``$P@J/&[S<N1H`">N6``(`#.R6`"$>5KGDT&FY@0`9N8``&+F!
M`!:Y"``0[$<`.@56PCJ/&[S<N0@`0;GHT`/K&``"``SL&``A'E;LT2"_`%6Y
MY-")N>80:;F``&>Y@0!H[(0@OP!5N0@`8.Q$.[\E6>,`LA@`!.Q(`#H%5KD(
M`$;L9""_`%7L-#N_)5GC0+(@``3""H\;O-RY&@`)PDJ/&[S<ZY<``@`,[)<`
M(1Y6N>30>;F!`!FY@``8N8$`%[D(`!"YZ-`$[#8`.@56N0@`,>L8``(`#.P8
M`"$>5NS1(+\`5;GF$(FYY-!YN8``AKF!`(>Y"`"`XP"R*``$XW"R,``$P@J/
M&[S<N1H`">Q#(+\`5<)ZCQN\W.PS.[\E6>PT`#H%5KD(`#CKA@`"``SLA@`A
M'E:YY-!HN8$`&+F``!2Y@0`6N0@`$+GHT`?LDR"_`%7L,SN_)5GL.0`Z!5:Y
M"``QZQ0``@`,[',@OP!5[!0`(1Y6[#,[OR59[-$@OP!5N>802+GDT&BY@`!)
M[#<`.@56N8$`1KD(`$#C`+(X``2Y"``T[$,@OP!5[&,[OR59XS"R0``$P@J/
M&[S<N1H`".N)``(`#.R)`"$>5KGF@)&YY-`8[&0`.@56N8``E\(ZCQN\W+F!
M`)&Y"``]L\$`$[D(`)"SS0`!N0@`ENL7``(`#.P7`"$>5NS1(+\`5;GDT'BY
MYA`X[&D[OR59N8``-+F!`#?L>2"_`%7CD+)(``3L9P`Z!5:Y"``PPIJ/&[S<
MN0@`-K/!`$FSS0!DZY0``@`,N1H`:.R4`"$>5NQ#(+\`5;GDT`FY@0`9N8``
M%[F!`!"Y"``6XV"R4``$[#,[OR59PFJ/&[S<N>C0!NPT`#H%5KD(`#'K%P`"
M``SL%P`A'E;LT2"_`%6YYA!YN>30B;F``'2Y@0!XN0@`<.,`LE@`!.R#(+\`
M5<(*CQN\W.PS.[\E6;D:``GL.``Z!5:YZ#"7ZS0``@`,['D@OP!5[#0`(1Y6
M[$D[OR59XY"R8``$N>308[F!`!/"FH\;O-RY@``8N8$`%KD(`!"YZ-`)[$<`
M.@56N0@`0>L8``(`#.P8`"$>5NS1(+\`5;GF$&.YY-"#N8``9[F!`&BY"`!@
MXP"R:``$[(0@OP!5P@J/&[S<[$0[OR59N1H``^Q(`#H%5KGH0#;L8R"_`%7L
M0SN_)5GC,+)P``3KEP`"``S".H\;O-SLEP`A'E:YY-!YN8$`&;F``!BY@0`7
MN0@`$+GHT`/C,+)X``3L1@`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6['$@OP!5N>1P
MB;GF$-G".H\;O-RY@`#6N1H`.;F!`-CKE@`"``SLA""_`%7LE@`A'E:Y"`#0
M[$0[OR59[$@`.@56N0@`3>QD.[\E6>S4(+\`5;GFD$&Y!``6XV"R@``$N>1P
M">P=`#H%5KF``$C":H\;O-RY@0!`N0@`0[GH<#:Y"`!!ZQ@``@`,[!@`(1Y6
M['$@OP!5N>80B;GD<&FY@`"-N8$`AKD(`(/C,+*(``3K;0`"``S".H\;O-RY
M&@`YL\$``^,PLI``!.P$.[\E6<(ZRF+!UNP$(#H%5KD$`):SS0!@N0@`@.R=
M`"$>5NS8.[\E6;GD<`GLV"`Z!5:YZ'!SL\$`%[/-`#'`2@````"Y@0`9N8``
M%+F!`!"Y"``6N0@`'>S1.[\E6>S1(#H%5NMT``(`#.,`LI@`!.QT`"$>5KGG
M<$FY@@!(N1H`-+D(`#WCT+*@``3""LIBP=;L:"*_/EFY&@`)[&@"(1Y6PMK*
M8L'6N>=@1[D:`->Y@@!![(,[OR59N1H`!.R#(#H%5KD(`(#LF#N_)5GLF"`Z
M!5;L<2*_/EFSP0!Y['$"(1Y6XY"RJ``$N00`';/-`->YYW!&PIK*8L'6N8(`
M0[D:`):Y&@`4[&,BOSY9N0@`'>QC`B$>5NPQ.[\E6>PQ(#H%5KGG8`?C0+*P
M``2Y@@`(N1H`D+D(`)/L."*_/EGL.`(A'E;C@+*X``2YYS`&PDK*8L'6N8(`
M`;D:`$?LV3N_)5FY&@!`[-D@.@56PHK*8L'6N0@`3;D:`(;L82*_/EGL80(A
M'E;L%#N_)5GL%"`Z!5:SP0`!XQ"RP``$N>=@T\(:RF+!UKF"`-FY&@`3['DB
MOSY9L\T`,.QY`B$>5N.0LL@`!+D:`(W"FLIBP=:Y"`"#N>=PUKD:`):Y@@#4
M[`@[OR59N1H`'>P((#H%5NQD(K\^6;D(`!#L9`(A'E;L03N_)5GL02`Z!5:Y
MYV`'XS"RT``$N8(`"+D:`)"Y"`"4[$@BOSY9[$@"(1Y6XX"RV``$N>=`!L(Z
MRF+!UKF"``&Y&@`W[-D[OR59N1H`,.S9(#H%5L**RF+!UKD(`#VY&@"&[&$B
MOSY9[&$"(1Y6[!,[OR59[!,@.@56L\$`4>,0LN``!+GG8-3"&LIBP=:Y@@#9
MN1H`%.QY(K\^6;/-`$7L>0(A'E;CD++H``2Y&@"-PIK*8L'6N0@`A+GG<-:Y
M&@"6N8(`T^P(.[\E6;D:`!WL""`Z!5;L8R*_/EFY"``0[&,"(1Y6[#$[OR59
M[#$@.@56N>=@!^-`LO``!+F"``BY&@"0N0@`D^PX(K\^6>PX`B$>5N.`LO@`
M!+GG,`;"2LIBP=:Y@@`!N1H`1^S9.[\E6;D:`$#LV2`Z!5;"BLIBP=:Y"`!-
MN1H`ANQA(K\^6>QA`B$>5NP4.[\E6>P4(#H%5K/!``'C$+,```2YYV#3PAK*
M8L'6N1H`$[/-`#"Y@@#9['DBOSY9N1H`C>QY`B$>5KD(`(/CD+,(``3C,+,0
M``3L"#N_)5GL""`Z!5:YYW#6PIK*8L'6N8(`U+D:`):Y&@`=[&0BOSY9N0@`
M$.QD`B$>5L(ZRF+!UKGG8`>Y&@`WXW"S&``$[$$[OR59[$$@.@56N8(`".S8
M(K\^6;D:`)#LV`(A'E:Y"`"4N>?0ANQ).[\E6;F"`('L22`Z!5:Y&@`XPGK*
M8L'6N0@`-+D:`';L82*_/EGL80(A'E;L$SN_)5GL$R`Z!5:SP0!1XQ"S(``$
MN>=@3>R)(K\^6;F"`$GLB0(A'E:YYX"6N8(`D\(:RF+!UKD:`!VY&@`9[),B
MOSY9[),"(1Y6XS"S*``$L\T`U;D:`'3".LIBP=:SP0!SL\T`1[D(`'VYYY`X
M[-<@OP!5N8(`-^P'.[\E6;D(`%3L#0`Z!5:Y&@!6N0@`$.QQ(+\`5;D:`%/L
M83N_)5GL9P`Z!5:Y"`!EN0@`?N.0L*@`".>6<``(8NOM``(`#.?YT``.:.SM
M`"$>5KGHH*[GNI``"&+C@"`@``CG"]``#FC`B@````#C@"`@`"3G\"``.`[G
M`"`0.`[C(+"@``35![,P("BG=``&ZV^S:``$!_[`Y?__\;@'!P<'!P<'!P<'
MZV_P,``DN00`[^/P_V#_<>/@\```)+D$`+_L*`!<`'S$&```0C#C8!````*G
MA`!3XP`@``"4N00`<KD$`-.Y!`""E0`@`*>$`$[L"``,/7Y!@(`!XP"```"4
ME0"``*=T__8;A^.08````J>$`!^Y%`"(N00`IKD$`$BY!``WN00`*<#E___P
M+^PF``D`?D$HD`"5/2``IX0`#T&@H`CCD*````*G=/_IN00`*>MOL-``!`?^
MN>E@.D&8D`'K0P`#``I00-``N00`*>MOL-``!`?^IYD``+D$`"GK;[#0``0'
M_J>(``"G]/^_!P<'!P<'ZY_P2``DLD\`H+D$`._KJ@`@``VR3P"AX_#^R/]Q
MX^#P```DN00`DKD$`+]!,+"@T@>Q,*`HP.7___%-["8`(0!^&!)8(+"XISA`
M`,`K``#P`.PC``B`=J4/H`#L(``38':Y!``IISD``L#E___QLQ`2IQK__X@0
M`!^G]``$IQ@``-4'L3"@*+D4`"&G=``&ZY^Q@``$!_[`Y?__\.P'!^MO\#``
M)+)/`)"Y!`#OZYD`(``-LD\`D>/P_L#_<>/@\```)+D$`+_2![$XD"CL*``)
M`'RY!`!BE0`@`*=T``O5![$XD"BG=`"'ZV^Q<``$!_[`Y?__\:^Y!`"B["C_
M\@!\N00`*L#E___P%>PH`%H`?$&`(!.5+B`3IW0`!I4`@`&GA/_PE2X@$Z>$
M`%>G&0``[$8\OP!5IX0`6J<Y``^Y"0`TYP-@```WIQL`$.<@`#``@:>$``SG
M`6``0`:G&P`0YR``,`"!IW3_^.<"``<`(4%0,`&YA`!PN2``<[GB(!6G)``U
MX^%_\/]Q[$@\OP!5IQD``*>$`#*G.0`/N0D`-.=#(!,`-Z<;`!#G9$`P`(&G
MA``HYT$@$T`&I_3_]KD$`"K`Y?__[F:Y!``FP.7__^ZQI_3_AI4N@`&G=/^I
ME0"``J>$_X^G]/^CISD`#Z?T_[3`Y?__\#ZG.0`/I_3_W.<&``<`(4%0,`&Y
MA`!PN2``<[GB(!6G)/_QXR%_\/]Q&N*GZ@`"N10`?KD$`"?`Y?__[E#C@/"@
M`"2G.0`"N00`@KD$`$?`4```$Z;`Y?__\-&Y!``H03"PJ,#E___O"NPH``W_
M?EC@L,"G&$``P.L``/``[.$`#X!VN00`*,#E___P.+D$`"C`Y?__\'.G]/\Y
MN00`*,#E____!*?T__0'!P<'!P<'!P<'!P<'!^MO\#``)+)/`)#`$```0(/K
M:0`@``WCH!````2R3P!AN00`[^/P_UC_<>/@\```),1(``!`=.,J8```!+D$
M`+_`4```,ZC`,```$U+`Y?__\(KE2/"@``#C*F````3`0```#^'`8```%*K`
M,```$TZY!`!6P.7__^[FZV^PV``$!_X'!P<'!P<'!P<'!P<'!^MO\#``)+D$
M`._C\/``_W'C`/_X`"#C\/]8_W'C`/"@`"#CX/```"2R3P"@ZZH`(``-LD\`
MH;D$`+_C$+"@`7'2!Q``H"BY!`"#09"PH+D$`'*Y!``YITD/_\`@```3&<#E
M___N2.PL`!(`?NP"__\`V!@2N10`($$RL*"5`#``IW0`(NP&`!\`?L!````_
M^^-00```!+D$`#?C):````2Y!`!(P.7__^WFXY"PH`%QU0>0`*`HIW0`*>MO
ML-@!!`?^&!"Y%`!AN00`*;D$`$:G.0`OP.7__^X>["C_V`!\P.```#_0XX#@
M```$N00`5N,HH```!+D$`$FY!``WP.7__^ZYI_3_T\#E___O%`<'ZV_P,``D
MLD\`8+D$`._K9@`@``VR3P!AX_#_./]QX^#P```DN00`O]('L,!@*+D$`**Y
M!`"3E3TP`*=T``1!D#`!IQD``.PY/+\`5:>$`'FG*0`/N0D`(^<"D```-Z<;
M`!#G(``P`(&GA``,YP&0`$`&IQL`$.<@`#``@:=T__CG`@`'`"%!0"`!N80`
M4+D@`%*YXB`4IR0`5.-Q7_#_<;D$`"KC<+"P`"1!,+"\P.7___T)N00`@NPH
M`$L`?*?9``#L`CR_`%6GA``_IWD`#[D)`'#G1R```#>GVP`0YV1`,`"!IX0`
M#.=-@`!`!J?;`!#G9$`P`(&G=/_XYQ8`!P`A03!P`;F$`.&Y(`#GN>(@TZ<D
M`!KC(+"P``3C3>_P_W'L)`$0P&7C@+"\`!3$V```/PGK>``#``VG]`!<IRD`
M#Z?T_Y6G>0`/I_3_S\38```^^>-PT```!.,0<````J>$`.>Y!``7IX@``!CH
MIXH``4$0$`CC,!````*G=/_XI^H``[D4`#[K(P`#``WC(+"@`"3`0```/U;C
M$$```!*GA`":XS"PH``$N00`)\#E___M6>,@L*@`).,@T```).PH`'T`?+D4
M`.CK?@`#``WC0+"H``10@+"\IXH``;D4`(CK*``#``U!4D``Y4A0````XP"@
M``"4N00`6I4`H`"G=``-I_0`D4%04`'C`%```)25`%``IX0`!>P&__<]?KD)
M`%JY%``5XS"PL``$N00`AT$C$`+C@-````C`Y?__["+C((```"3L*``Y`'SC
MX-````3C(*```)#C=^````1!H*`!0B!P`!A"["8`$`!\I_0`+N/0H```D$&@
MH`%"T%`!&$WLV``D`'Q"0+"PN00`5Y4]L+!!<'`!IW3_[9(]4`"G&0``XP&0
M``"00@%0`:<;``'L!O_Y`'S5![#`8"BG=``^ZV^P^``$!_ZY!`!7I_3_Y^,@
ML*``!,!0```^L^5,4````<#E___KS>,@L*@`).PH_^0`?.-0L*``!+D$`#>Y
M%`!XZW<``P`-N00`1\#E___N:.,0L*@`!.,0T```)*?T_U>G&0``I_3_?^5(
ML*``$*>(``"G]/\NP.7__^URISD``./CD```D$+C@`"G.P`![.;_^0!\I_3_
ML`<'LD\`(,`0```^!NM2`"``#>,P$```!+)/`%&SP0`+N00`O^,C4```!,1(
M```]^+/-`+#`4```,2_`,```$-G`]/__[A$'!P<'!P<'!P<'!P?K;_`P`"2Y
M!`#OX_#P`/]QXP#_^``@X_#P`/]QXP#_^``@X_#_2/]QXP#PL``@X^#P```D
MLD\`@.N(`"``#;)/`(&Y!`"_XQ"PL`)QT@<0`(`HP.7__^S/P````!#(XP#P
MH``DN00`8N.@L*\!<:=)$`&G.0`"N00`*L!0```0L<#E___MN+D$`"I!8+"N
MITD0`+D$`#;`Y?__Z\WL)``Q`'[L<@`!`-BY!`"BN10`=[D$`"?`Y?__ZPZY
M!`"2["@`$@!\N10`JKD$`%>Y!``VN00`2L#E___K?D$JD`"2`"``XS"PL`)Q
MU0<P`(`HIW0`#+D$`"GK;[#H`@0'_J>9``"G]/_PP.7__^RU!P<'![/!``NY
M!`"_L\T`L,#T____<@<'!P<'!P<'!P<'!P<'ZV_P,``DN00`[^/P\`#_<>,`
M__@`(./P_JC_<>,`\5``(./@\```)+)/`-#KW0`@``VR3P#1N00`O^,0L5`!
M<=('$`#0*+D$`)*Y!`"#P"```!`X03"PO,#E___ZQ*<Y`"^Y!`"BN00`*<#E
M___L>^PH`!D`?,`@```0*;D$`#G`Y?___5"Y!``IXW"Q4`%QU0=P`-`HIW0!
MG.MOL8@!!`?^N00`*,#E___K?<`P```0%<#E___JQ[D$`&+L*/_=`'SL>3R_
M`%5!`+#`XP"PL``D08"Q4)4`8`"GA`"V[*@`#P!\IP@``+D$`#:Y!``JLET`
M,J<4__ZGA`"6IUD``.Q&/+\`5:>$`2>GZ0`/N0D`Y.<.8```-Z=;`!#G(``P
M`(&GA``,YP5@`$`&IUL`$.<@`#``@:=T__CG$@`'`"%!`.`!N80`,;D@`#ZY
MXB!0IR0!`N,U/_#_<>/C;___<>QN`'^@9;GI8"ZG(0`!IX0`#I4OX`"G=`#S
MD@#@`./@[___<>QN`!F`9.M2``$`#)4OX`"G=`#DD@#@`.LO[___5:=T`-WK
M`.___U+CX._^_W&G5__OIVD``.Q>/+\`5:>$`0.G&0`/N0D`%><1X```-Z=K
M`!#G,1`P`(&GA``,YQ;@`$`&IVL`$.<Q$#``@:=T__CG0P`'`"%!`!`!N80`
M)+D@`"&YXB!@IR0`WN,V+_#_<;D$`&ZG]``CE0"@`:=T`!K`,```#UFG*0``
MP.7__^H)N00`8NPH_Q\`?)4`8`"G=/].[*@`!P!\E2Z@`*>$_^:G.0`!P&``
M``\RI^D``.QX`'4`?*<9``^Y"0`7YU&0```WI^L`$.=U4#``@:>$``SG7I``
M0`:GZP`0YW50,`"!IW3_^.='``<`(4%0$`&YA``DN2``(;GB(.6G)`!/X^XO
M\/]Q00XP`:<Y#__L`_[;(&7CD/"H`"3`$```#P;C$/"@`"2G.0`"N00`*,!0
M```/<J=)$`#`Y?__Z^OC,+"P``2Y!``HP.7__^HC[";_D@!^6&"PV*5/@`#`
M:P``\`#L9/^(8':Y!``HISD``<#E___KO^PF_WX`?KD$`#C`(```#LO`Y?__
M^_2Y!``HP.7__^HOI_3^H:<9``^G]/^:I^D`#Z?T_N>GZ0``[$8\OP!5IX0`
M+*<9``^Y"0`4YT%@```WI^L`$.=D0#``@:>$``SG3F``0`:GZP`0YV1`,`"!
MIW3_^.<&``<`(4$@$`&YA``PN2``,;GB(.*G)``'XSX_\/]QI_3_4J<9``^G
M]/_BIQD`#Z?T_PO`Y?__ZKD'!P<'!P<'!P<'!P?KK_!0`"2Y!`#OX_#_8/]Q
MX^#P```DN00`HKD$`+^G.0`OP.7__^L_["@`!0!\0:`@`;D$`"KKK[#P``3`
M]/__Z<('!P<'!P<'!P<'!P<'!^N/\$``)+D$`._C\/``_W'C`/_X`"#C\/]8
M_W'C`/"@`"#CX/```"2R3P"@ZZH`(``-LD\`H;D$`+_C$+"@`7'2!Q``H"CL
M*`"9`'RY!``RE0`@`*>$`)*GB0``[$(\OP!5IX0`AZ<I``^Y"0`DYP(P```W
MIXL`$.<@`#``@:>$``SG"#``0`:GBP`0YR``,`"!IW3_^.<"``<`(4%0(`&Y
MA`"0N2``DKGB((6G)`!BXXB?\/]QI^D0`.Q(``$`V>Q.`&T@94&0L*"Y!``I
MP.7__^M!XQB?__]Q[!D`*\!EN>F0,:<1``&GA``.E2\0`*=T`""2`!``XQ`?
M__]Q[!D`&8!DZT,``0`,E2\0`*=T`!&2`!``ZR\?__]5IW0`"NL`'___4N,0
M'_[_<:='_^^Y!``IISD`+\#E___JC.PH`!T`?.PI``7`99(`(`"Y!``IP.7_
M_^D/XU"PH`%QU0=0`*`HIW0`'^N/L.@!!`?^IRD`#Z?T_X?C(+"@`7'5!R``
MH"BG=``/P"````V"ZX^PZ`$$P/3__^CNIRD``*?T_]W`Y?__Z;<'!P<'!P<'
M!^N?\$@`)+)/`)"Y!`#OZYD`(``-LD\`D>/P_U#_<>/@\```)+D$`+_2!["H
MD"A!H+"DN00`.L`@```-8L#E___WXNPH`"X`?,1(```Z'.,@L*0`%.L2``,`
M#>,00```".-0$`@`!.-0$```).Q8_^,`?.,`$!``!$$0$`CC`!```"3L!O_X
M`'RY!``ZP"````TWP.7___>W[";_V`!\N00`.L`@```-,<#E___WK.PH`"X`
M?,18```YYN,0L*0`%.OA``,`#>/@4```".,`X`@`!.,`X```).P(_^,`?.,P
MX!``!$'@X`CC,.```"3L-O_X`'RY!``ZP"````T&P.7___>![";_V`!\N00`
M.L`@```,_\#E___W=NPH`"X`?,18```YL./@L*0`%.M.``,`#>-`4```".,P
M0`@`!.,P0```).PX_^,`?.,@0!``!$%`0`CC($```"3L)O_X`'RY!``ZP"``
M``S4P.7___=+[";_V`!\N00`.L`@```,SL#E___W0.PH`"X`?,0X```Y>N,@
ML*0`%.L2``,`#>,0,```".-`$`@`!.-`$```).Q(_^,`?.,`$!``!$$0$`CC
M`!```"3L!O_X`'RY!``ZP"````RCP.7___<5[";_V`!\N00`.L`@```,G,#E
M___W"NPH`"X`?,1(```Y1.,0L*0`%.M1``,`#>-00```".,`4`@`!.,`4```
M).P(_^,`?./@4!``!$%04`CCX%```"3LYO_X`'RY!``ZP"````QQP.7___;?
M[";_V`!\N00`.L`@```,;L#E___VU.PH`"X`?,1(```Y#N-0L*0`%.LU``,`
M#>,P0```"./@,`@`!./@,```).SH_^,`?.,@,!``!$$P,`CC(#```"3L)O_X
M`'RY!``ZP"````Q#P.7___:I[";_V`!\N00`.L`@```,$,#E___VGNPH`"X`
M?,3H```XV.,@L*0`%.L2``,`#>,0X```".,P$`@`!.,P$```).PX_^,`?.,`
M$!``!$$0$`CC`!```"3L!O_X`'RY!``ZP"````OEP.7___9S[";_V`!\N00`
M.L`@```,",#E___V:.PH`"X`?,0X```XHN,0L*0`%.M!``,`#>-`,```".,`
M0`@`!.,`0```).P(_^,`?.-00!``!$%`0`CC4$```"3L5O_X`'RY!``ZP"``
M``O=P.7___8][";_V`!\N00`.L`@```+U\#E___V,NPH`"X`?,0X```X;.-`
ML*0`%.OD``,`#>/@,```".-0X`@`!.-0X```).Q8_^,`?.,@X!``!$'@X`CC
M(.```"3L)O_X`'RY!``ZP"````NLP.7___8'[";_V`!\N00`.L`@```+IL#E
M___U_.PH`"X`?,18```X-N/@L*0`%.L>``,`#>,04```".,@$`@`!.,@$```
M).PH_^,`?.,`$!``!$$0$`CC`!```"3L!O_X`'RY!``ZP"````M[P.7___71
M[";_V`!\N00`.L`@```+/<#E___UQNPH`"X`?,0H```X`.,0L*0`%.LQ``,`
M#>,P(```".,`,`@`!.,`,```).P(_^,`?.-`,!``!$$P,`CC0#```"3L1O_X
M`'RY!``ZP"````L2P.7___6;[";_V`!\N00`.L`@```+/\#E___UD+D$`#+L
M*``)`'S`(```"RK`Y?__^"6Y!``ZP"````LUP.7___5]N00`,NPH``D`?,`@
M```+,\#E___X$KD$`#K`(```"S'`Y?__]6JY!``R["@`&@!\P"````K1P.7_
M__?_U0>PJ)`HIW0`(\`P```+T<`@```*X^N?L/@`!,#T___W[KD$`#K`(```
M"Q7`Y?__]4:Y!``R["C_Y0!\P"````K;P.7___?;I_3_W,#E___FY@<'!P<'
M!^NO\%``)+)/`*"Y!`#OZZH`(``-LD\`H>/P_U#_<>/@\```),`@```*N[D$
M`+]!,+"DT@>PJ*`HP.7___44["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`
M$.PQ/[\!6=4'L*B@*+D4`".G=``*ZZ^Q```$!_ZG.```I_3_\\#E___FH0<'
M!P<'!P<'!P<'!V``\(!@(/"(8$#PD&!@\)CK/_`8`"3$&```-TVR3P``N00`
M[^/P_SC_<>/@\```)+D$`$+K,``@``WC(!````2R3P`QN00`OT'@L,A!4+"@
MT@>PP#`HX^"PN``DY4BPH``!Y4BPJ```06"Q:.-@L+``)*<Y``+`Y?__YBVG
M*0#_P.7__^7H!P<'!P<'!P<'!^MO\#``)./@\`#P<>/P\`#_<>,`__@`(+DA
M`/ZG)/_XN00`_N/P_U#_<>,`\*@`(+)/`(#C`/"P$''C`/```"3KB``@``VR
M3P"!N00`O^,0L*@0<=('$`"`**<Y``"Y!`!BITD``L#E___D;>QR__\`V>PW
M,(``5>QT`*4`?+D)`'/L=`",`'Q!D+"@P*```#;:N00`-[D$`":G20``P.7_
M_^11["@`H/]\N00`.;D$`";`00`!``C`Y?__YE3L*`"-_WZY%`!"[$P`8`=]
MXQ2?^/]Q[!D`6D!E[%$^OP!5U0<0`*``IX0`:.,0'___<>P9`$Q`9>Q8`"0`
M?.Q8`!8!?.Q8``L"?-4'$`"@`*>$`%3C$!___W'5!Q``H`"GA`!,XQ`?__]Q
MU0<0`*``IX0`1.,0'___<>P9`"A`9=4'$`"@`*>$`#GCX!___W&Y!``>U0?@
M`*``IX0`+^,0[___<=4'$`"@`*>$`"?C$._^_W'5!Q``H`"GA``?XQ#O_?]Q
M[!G_WJ!EPG0``0``P`'__P``['#_?V!DIRG__^-@L*@0<=4'8`"`**=T`"/K
M;[#@$`0'_KGID"&Y"``GI_3_\*<[___`(?__``"Y@0`RISL``:?T_U7`(```
M"9#`Y?___LG`(```"8/`Y?___L/`Y?__Y5@'!P<'!P<'!P<'Z[_P6``DN00`
M[^/P_V#_<>/@\```)+D$`+_`Y?__XR/`Y?__XP#L*``&`'SC("````3KO[#X
M``0'_@<'!P<'!^MO\#``)+)/`)"Y!`#OZYD`(``-LD\`D>/P_T#_<>/@\```
M)+D$`&*Y!`"_P"````E,03"PM-('L+B0*,#E___S8NPH`!H`?+D$`**5`"``
MIX0`$[D$`#;`Y?__XR3L*``<`'S5!["XD"BG=`!CZV^P\``$!_[5!["XD"BG
M=`!:N00`-L`@```)(.MOL/``!,#T___UV*<9``#L-CR_`%6GA`!$IRD`#[D)
M`"/G`F```#>G&P`0YR``,`"!IX0`#.<!8`!`!J<;`!#G(``P`(&G=/_XYP(`
M!P`A04`@`;F$`%"Y(`!2N>(@%*<D`!_C@5_P_W&GZ0``[!H\OP!5IX0`'*<I
M``^Y"0`AYT*@```WI^L`$.=D0#``@:>$`!+G3J``0`:G]/_VIRD`#Z?T_\K`
MY?__Y)BG*0`/I_3_\N<V``<`(4$`(`&YA`!#N2``0KGB(."G)/_QXUY/\/]Q
M08A0`KD$`"C`Y?__XJWCH/"H`"3`H```"$+CH/"@`"2Y!`!(P%````BQN00`
M@J<Y``+`Y?__Y2C5!["XD"BG=/_*N00`.,`@```(D.MOL/``!,#T___U2`<'
M!P<'!P<'!P?K;_`P`"2Y!`#OX_#^(/]QX^#P```DLD\`T*?K__A@@.``Z]T`
M(``-LD\`T;D$`+_2!['0T"A!,+#4XS"PR``DP!```#4`TD>P^!`0T@^PX!!8
MT@>P\!!HXR"PP``DP"````?@P.7___)N["@`"0!\N00`DI4`(`"G=`&#P.7_
M_^'RP.7__^'/["@`.`!\XW`@```"IX0`,J?I``#L-SR_`%6GA``GIRD`#[D)
M`"/G`G```#>GZP`0YR``,`"!IX0`#.<.<`!`!J?K`!#G(``P`(&G=/_XYP(`
M!P`A04`@`;F$`&"Y(`!BN>(@Y*?$`2FG*0`/I_3_YT%@L.#C(&````*GA``6
MXS"PR``$P.7___(:["@`!P!\E0`@`*=T`-VG:P`(XR!@```"IW3_[J<I``VG
MB0`-P.7__^'EIYD`#;D$`**SP0""P'````?FIU@`4[D$`$FY!``JN80`9:<Y
M``+`4```!]W`Y?__Y%RY(0")N00`6;GBH%BYZ9`5IQL``KDA`!6YXE`5N0D`
ME4%P<`%!H*`"XYD?_O]QXU!P``"4E0!P`*=T_];CH+#(``1!<+$8P"````>$
MI_0`":=[``CC('_X_P*GA``@N00`.L#E___QN+D$`&+L*/_R`'R5`"``IX3_
M[<#E___R).PH_^@`?KD$`";`Y?__XH2Y!`!B["8`'0!\08"P^.-@@````J>$
M`!65`&``IX0`V[D$`";`Y?__\@?L)@"]`'ZGBP`(XV"````"IW3_[Z?I``#L
M-CR_`%6GA`#!IRD`#[D)`"/G$F```#>GZP`0YS$0,`"!IX0`#.<>8`!`!J?K
M`!#G,1`P`(&G=/_XYP,`!P`A04`@`;F$`%"Y(`!2N>(@Y*<D`)RSS0!XXYY?
M\/]QIQD``.RG/+\`5:>$`Q^GZ0`/N0D`ZN=><```-Z<;`!#G=5`P`(&GA`"1
ML\T`..=1,`!`!J?T__3`Y?__XA7L*/\B`'RY!`!RI^D``.PR/+\`5:>$`$.G
M*0`/N0D`(^="<```-Z?K`!#G9$`P`(&GA``,YTYP`$`&I^L`$.=D0#``@:=T
M__CG!@`'`"%!0"`!N80`8+D@`&*YXB#DIR0`'N..;_#_<>N8``$`#:>;``&Y
M!``IP.7__^#7XU!P``"4N00`HI4`<`"GA``YN00`B;/!`(*G]/[PIRD`#Z?T
M_\O`Y?___6'5!['0T"BG=``K:("QV+D$`"GK;[(0``3`]/__X;*Y!``FIXL`
M",#E___AJ[D$`&+L*/\L`'RGZ0``[#8\OP!5IW3_0Z<I``^G]/]-IVD``*?T
M_S2SP0""I_3^Y\#E___B8.<G``<`(4$`X`&YA`!"N2``3KGB(!"G)`)UXU%/
M\/]Q&EFG6@0$N10`I;D$`"K`Y?__X'9@@/"PP!````8-XQ#PH``DP)````:!
MXY#PJ``DN00`<J<Y``*Y!`!*P%````9PP.7__^+LN00`)Z<Y`<#`Y?__X=7L
M)@`+_W[`Y?__X9]88"``[&8!9!%^08"Q0+/!`(BY!``XN00`)\#E___B/QB"
M["8`#0!^6."Q6*<X0`#`ZP``\`#LXP`H@';$J```,KZY!`!GXW"PP``$XR"@
M```$XU!P```$P$````97ISD``L#E___B"Z>9``#5!['0T"BG=/^#N00`*6B`
ML=CK;[(0``0'_EB0L5S`Y?__W[?LDO_68'98`+%8IR@!P,`+```!_^P"_\Q@
M=KD$`"K`Y?__W_7C,+#(``2Y!`"2P"````9.P.7___`*N00`,NPH`.X`?.-`
ML,``!.,@0```!,#E___U#+D$`&+L*`#@`'RG&0``[.8\OP!5IX0`Y:<I``^Y
M"0`NYP)@``@WIQL`$.<@`#`.@:>$``SG`6``2`:G&P`0YR``,`Z!IW3_^.<R
M``<$(4$`(`&YA`!#N2``0KGB(!"G)`#`XU%/\/]Q[%P`(`-^N10`%<#@```&
M!.,A;_S_<:<(``"R70#BIQ3__J=T``_L6`$W!'ZG6O_[N10`-4%#8`"5+T``
MIX0!+.,PL,@`!,`@```%/\#E___OG^PH`+,`?.,0(```E.P8`*T`?NP8`*HP
M?L`P```&"L`@```%*L#E___R*L#E___@]^,@\*@`)+D$`&?`````!/OC`/"@
M`"3`<```!B7C</"P`"2Y!`!*N00`*<!0```%QZ<Y``+`Y?__X=JG]``PP.7_
M_^"56#`@`*<^`!&G=``QP.7__^#,XR#PJ``DP%````8"XU#PN``DIXH``<``
M```$RN,`\*``)+D4`!CC$/"P`"2Y!`!*N00`*<!0```%GJ<Y``+`Y?__X:JY
M!``IISD!P,#E___@D^PH_\O_?KD$`':Y!``GP.7__^%9N00`.<`@```$D\#E
M___QP;D$`"G`Y?__^YRG]/[CXU"PP``$IQD``.-@4```!.SF/+\`5:=T_Q^G
M*0`/I_3_*>-`L,``!,0H```Q<[D4`&;C8/"@`"3C4$````3C("````2Y!`!G
MP$````3LISD``L#E___@OJ?T_K.Y!``FISD``,#E___A);D$`&+L*/]0`'[`
MY?__^CWC(+#(`"2Y!`!2["3_10!\ITD``.,P7_;_<;D$`";`Y?__WLNY!``F
M03"PVJ=)``;`Y?__X-+L)@"6!GS`0```)%G5!4``L-JG=/\FX^"PR``$ITD`
M`.,P[\[_<;D$`";`Y?__WJJSS0`XN00`)J=)`"C`Y?__X+'L)@!U*'Q@@/"H
MP#````5%XS#PL``DP(````0/XX#PH``DD@"Q:+D$`$JY!`!GN00`*<!0```$
MU:<Y``+`Y?__X/"G]/]2XU"PP``$XQ!0"``"IX3^T*?I``#L`3R_`%6GA``]
MIRD`#[D)`"#G0A``"#>GZP`0YV1`,`Z!IX0`#.=.$`!(!J?K`!#G9$`P#H&G
M=/_XYS8`!P0A05`@`;F$`$.Y(`!"N>(@Y:<D`!CC[D_P_W'L[/Z?`WWC/A_\
M_W'`(```!(6G"```LET`(Z<4__ZYXH!AI_3^CJ<I``^G]/_1I^D`#Z?T_._`
M(```!'/`Y?__^3X'!P<'!P?K;_`P`"2R3P"@P)```#!SZZH`(``-XQ"0```$
MLD\`H;D$`._C\/]0_W'CX/```"3C@:````2Y!`"_T@>PJ*`HT@"`L8"P07"P
MI,`@```#BKD$`#?`Y?__[?;L*``'`'R5,2``IX0`TL#E___U[.,@D```!.."
MH```!+D$`"BG60`#ITD``<`P```$1<#E___>&KD$`(+L*``?`'SC,"`0``3C
M8)````3C,#````3C)J````3`0```!"_`Y?__WA/C0(`0``3C,$````210#`-
MIW0`L^-@D```!*=9``/C)J````2G20`!P#````08P.7__]WIN00`@NPH`!P`
M?+D$`#?`(````Q/`Y?__[9RY!`!"["@`@0!\XQ"`$``$XR:@```$XS`0```$
MP.7__]W;XY"0```$ITD``>-IH```!,`P```#[;D$`";`Y?__W1O`0````_"Y
M!``RN00`)L#E___=P>,IH```!+D$`#>2`""QP"````+6P.7__^UDQ"L``#`I
MN00`<NPH`"P`?+D$`">G.0'`P.7__]ZU[`(``0#8[`P`%@%_["@`$Q%^Q*@`
M`#`-N00`4N,PH```!+D$`$?`(````\O`Y?__WSS5!["HH"BG=``YZV^PX``$
M!_[$*```+_3`Y?__^HW$*P``+_*Y!`!R[";_S`!\P"````.=P.7__]\?E0`@
M`:>$_S>G]/\LXU"`$``$Q.@``"_7XR!0```$XS#@```$P.7__^\BI_3_?^,F
MH```!,#E___>HJ?T_TG`Y?__WJT'!P<'ZX_P0``DLD\`D+D$`._KF0`@``VR
M3P"1X_#_4/]QX^#P```DN00`HKD$`+_`(````G]!,+"DT@>PJ)`HP.7__^S:
M["@`$P!\XQ`@``"4[!@`#0!^[!@`"C!^[*@`!P!\E0"@`*=T``O5!["HD"BG
M=``TZX^P\``$!_ZY!``JP.7___/AISD`+[D$`(+`Y?__WP+L*``%`'Q!@"`!
MN00`*,#E___=B*=)``3`,````IG`Y?__W1#L)O_9`'[5!["HD"BG=``*N00`
M*NN/L/``!,#T___M6,#E___>/0<'!P?KO_!8`"3`T```(@&Y!`#OX_#_8/]Q
MX^#P```DN00`OZ<I`(#`Y?__W%;G`-`@,`;G(-`0,`;G0-``,`;G`"``,`[G
M("`0,`[G0"`@,`[E2"`P``#E3"!X``#KO[#X``0'_@<'!P<'!P<'!P<'!P<'
MZV_P,``DN00`[^/P_UC_<>/@\```).-0("@`!+D$`)+K%``#``VY"``5["$@
MOP!5N00`A+D$`+_C0)`P``2Y!`"CN3$`4:?$``2G2P`!ZP@`'0`,N0@`!.<"
M````8N/@D'@`$N<`D"@P#J=T`$-!<)`X[(P`:#]^[%C_P`#8ZQ4`!@#>4!"P
MI.Q!``$`V.SD'[D&6>P._\``V4'>H`#K8``&``RG:P`!TC]P`*``N00`*4&@
MH$#`Y?__X+VG9__V6""PI*>*_\")(``&&X*Y%`"(N00`/;D$`">Y!`!(P.7_
M_]ZQ4("0>.MOL-@`!`?^IV@`0!MN&6A!<)`XN?(P:+D$`">Y&``NN00`.KD4
M`-:Y!`!-P.7__]Z6&#9:,)!X4#"0>.PV_^)`?AN&N00`*;D(`*VY%`"(P.7_
M_^!\I_3_FKD$`-JG]/_&!P<'!P<'ZW_P.``DP-```"$YN00`[^/P_V#_<>/@
M\```)+D$`+_C@#`H``2Y!`"CXW`P,``$[#@ZOSU9N10`$T%!H#B2@$``ISH`
M`;D$`))!$*`XN10`([D(`!+L/`!I.'ZG2`!`N?DP).Q#`!"`=J<J___K`@`(
M`-[L!@!Y`'ZY%@!2QE````!]N00`*L#E___@+-<WH#B@.&@`T`#KYP`0``SK
M%P`8``SK-P`(``SK2``8``SK*``(``SG`0```"+G#@`!`"+G`P`"`"+G!P`#
M`"+K>``0``SG!``$`"+G!P`%`"+G`@`&`"+G"``'`")@`*!PN00`*L#E___?
M]M(#D`"@!+D$`"K2`Y`$H`S2`Y`(H!32`Y`,H!S2`Y`0H"3K?[#8``3`]/__
MW4>G"``XN?DP4.P#_[*`=J=:___KY0`(`-[LY@`*`'ZY%@`UQC`````:I_3_
MHM?_$``0`$$0$0"GYO_[I_3_\M?_$``0`$$0$0"G!O_[I_3_@]<`$``0`-<`
M$``0``<'!P<'!P<'!P<'!\18```M7,#T___:S0<'!P?K;_`P`"2Y!``?I_O_
M8.,0\```),#````L)@<'XT#Q$``$ZV_PT``$!_0'!P```````@`!)7,O)7,`
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4```O<')O8R]S96QF+V5X90``+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%
M35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU
M3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!0
M05)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@``;'-E96L@9F%I;&5D``!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X```E<R5S)7,E<P``<&%R+0``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42```<&%R;```+G!A<@``<VAO<G0@<F5A9```)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P``&`!P
M97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`V,0!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?
M<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C
M:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@
M(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I
M(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ
M92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU
M;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E
M:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A
M<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM
M>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN
M?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P
M<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI
M.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE
M(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N
M;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G
M:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H
M(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H
M<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U
M9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB
M+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@
M)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U
M;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE
M?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO
M9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^
M>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I
M;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!
M1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO
M;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R
M="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB
M)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)
M4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D
M(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D
M(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R
M('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO
M)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@
M("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@
M)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I
M.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@
M/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=
M*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE
M>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F
M*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H
M/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U
M=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O
M=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<
M,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@
M>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L
M(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H
M95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I
M.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*
M)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F
M("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;
M9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R
M86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E
M<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A
M8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X]
M(#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR
M96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP
M+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H
M.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B
M.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D
M96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M
M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y
M<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D
M7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)0
M05)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`%5315(``%5315).04U%
M``!414U01$E2`%1-4``O=&UP`````````````,/2X?````````````````"8
MNMS^`````!`R5'8`````9T4C`0````#OS:N)``````````!P97)L>'-I+F,`
M`$-!0TA%```````````!&P,[````[````!S__WIX```&S/__?1@```$(__]^
M2````3C__Y2X```!?/__E:@```'@__^62````AC__YA8```"6/__F.@```*8
M__^9^````MS__YU8```#(/__G:@```,\__^>N````X3__Y[8```#H/__HK@`
M``/D__^C"```!!3__Z2X```$9/__JE@```2<__^JZ```!-#__ZMX```%`/__
MK7@```5,__^MN```!7S__Z]X```%X/__N'@```8\__^ZR```!H#__[NH```'
M$/__O!@```=`__^]:```!X#__[[X```'P``````````4``````%Z4@`!>`X!
M&PP/H`$'#@`````4````'/__?`@```!"```````````````4``````%Z4@`!
M>`X!&PP/H`$```````!`````'/__?0@``!9F`$J&#H<-B`R)"XH*BPF,"(T'
MC@:/!50.V`=*#0L#%C8*S\[-S,O*R<C'Q@P/H`%""P```````&````!@__^3
M-````.H`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[``DH-"P*8"L_.S<S+RLG(
MQ\8,#Z`!0@M<"L_.S<S+RLG(Q\8,#Z`!0@M."L_.S<S+RLG(Q\8,#Z`!0@L`
M```T````Q/__D\````">`$:)"XH*BPF,"(T'C@:/!5@.V`-.#0L":@K/SLW,
MR\K)#`^@`4(+`````#P```#\__^4*````@(`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%6`[@`TH-"V@*S\[-S,O*R<C'Q@P/H`%""P`````\```!//__E?@```""
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!60.R`)6#0L"0,_.S<S+RLG(Q\8,#Z`!
M````````0````7S__Y9(```!#@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#J`A
M3`[((EX-"P*&"L_.S<S+RLG(Q\8,#Z`!0@L```!````!P/__EQ0```->`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!5@.Z`)*#0L#`J(*S\[-S,O*R<C'Q@P/H`%"
M"P```````!@```($__^:,````$0`7@D+$$0-"U#+#0\```!$```"(/__FF0`
M``$,`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.H"%,#J!!3`[80EX-"P*V"L_.
MS<S+RLG(Q\8,#Z`!0@L````8```":/__FRP````2`$0)"Q!$#0M$RPT/````
M0````H3__YLP```#U`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#J`A3`[X(UX-
M"P)F"L_.S<S+RLG(Q\8,#Z`!0@L````L```"R/__GLP```!"`$:*"HL)C`B-
M!XX&CP5*#L`"3@T+7L_.S<S+R@P/H`$```!,```"^/__GNP```&H`$:(#(D+
MB@J+"8P(C0>.!H\%2@Z@(4P.R")>#0L#`30*S\[-S,O*R<@,#Z`!0@MD"L_.
MS<S+RLG(#`^@`48+`````#0```-(__^@3```!9H`1HD+B@J+"8P(C0>.!H\%
M6`[0`DH-"P,%/`K/SLW,R\K)#`^@`48+````,````X#__Z6T````A`!&B@J+
M"8P(C0>.!H\%6`[0`E`-"P)&"L_.S<S+R@P/H`%""P```"P```.T__^F$```
M`(8`8(8.APV(#(D+B@J+"8P(C0>.!H\%2@[H`EX-"P```````$@```/D__^F
M<````?8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@P.H($$6`T/1@[0@@1D#0L#
M`68*S\[-S,O*R<C'Q@P/H`%""P`````L```$,/__J"0````Z`$:+"8P(C0>.
M!H\%2@[``DH-"U[/SLW,RPP/H`$```````!@```$8/__J#0```&V`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!5@.X`).#0L"2`K/SLW,R\K)R,?&#`^@`4(+6@K/
MSLW,R\K)R,?&#`^@`48+`P$:S\[-S,O*R<C'Q@P/H`$`````6```!,3__ZF0
M```(^@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#H`%8`T+F!4#`VP*S\[-S,O*
MR<C'QM@,#Z`!1@L#`4H*S\[-S,O*R<C'QM@,#Z`!0@L```````!````%(/__
MLC0```),`$:&#H<-B`R)"XH*BPF,"(T'C@:/!60.T`)0#0L#`:0*S\[-S,O*
MR<C'Q@P/H`%""P```````$@```5D__^T0````-P`1H@,B0N*"HL)C`B-!XX&
MCP58#M`"3@T+`DP*S\[-S,O*R<@,#Z`!0@L"5@K/SLW,R\K)R`P/H`%&"P``
M``!````%L/__<Z0```*4`$:&#H<-B`R)"XH*BPF,"(T'C@:/!50.Z`).#0L#
M`;@*S\[-S,O*R<C'Q@P/H`%""P```````"P```7T__^TD````&(`1HL)C`B-
M!XX&CP50#L`"2@T+`D#/SLW,RPP/H`$``````#P```8D__^TT````4H`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%2@[(`F@-"P*V"L_.S<S+RLG(Q\8,#Z`!0@L`
M```\```&9/__M>````&$`$:'#8@,B0N*"HL)C`B-!XX&CP50#L`"2@T+`P$"
M"L_.S<S+RLG(QPP/H`%&"P``````$```!J3__[<P````#```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````))``````
M```D0``````````!`````````N$``````````0````````+Q``````````P`
M```````9D``````````-````````96``````````&0```````+NP````````
M`!L`````````"``````````:````````N[@`````````'``````````(````
M`&___O4````````"D``````````%````````#$``````````!@````````-P
M``````````H````````$;0`````````+`````````!@`````````%0``````
M``````````````,```````"]P``````````"````````!2@`````````%```
M```````'`````````!<````````4:``````````'````````$>``````````
M"`````````*(``````````D`````````&``````````>``````````@`````
M;___^P`````(```!`````&____X````````1<`````!O____``````````$`
M````;___\````````!"N`````&____D`````````$```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````N\``````````````````````
M````````&?X````````:'@```````!H^````````&EX````````:?@``````
M`!J>````````&KX````````:W@```````!K^````````&QX````````;/@``
M`````!M>````````&WX````````;G@```````!N^````````&]X````````;
M_@```````!P>````````'#X````````<7@```````!Q^````````')X`````
M```<O@```````!S>````````'/X````````='@```````!T^````````'5X`
M```````=?@```````!V>````````';X````````=W@```````!W^````````
M'AX````````>/@```````!Y>````````'GX````````>G@```````!Z^````
M````'MX````````>_@```````!\>````````'SX````````?7@```````!]^
M````````'YX````````?O@```````!_>````````'_X````````@'@``````
M`"`^````````(%X````````@?@```````"">````````(+X`````````````
M``````````````````````````!>T```````````````````````````````
M````````````````````````````````````````````````````P(``````
M`````````````"#0``````````````````#`"`I005(N<&T*````````````
M``````"E_@```````&7L``````````````````!FC````````&:0````````
MI?(```````!E\@```````*7Z``````````````````"EX@```````*7H````
M``````````````!H<D=#0SH@*%5B=6YT=2`Q,RXR+C`M.75B=6YT=3$I(#$S
M+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN
M;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M``````(````````".`````````(X``````````\````````````````````!
M```````````````3````!P`````````"`````````D@````````"2```````
M```D````````````````````!```````````````)@````<``````````@``
M``````)L`````````FP`````````(`````````````````````0`````````
M`````#1O___V``````````(````````"D`````````*0`````````-P````%
M```````````````(```````````````^````"P`````````"`````````W``
M```````#<`````````C0````!@````(`````````"``````````8````1@``
M``,``````````@````````Q`````````#$`````````$;0``````````````
M``````$``````````````$YO____``````````(````````0K@```````!"N
M`````````+P````%```````````````"``````````(```!;;____@``````
M```"````````$7`````````1<`````````!P````!@````$`````````"```
M````````````:@````0``````````@```````!'@````````$>`````````"
MB`````4```````````````@`````````&````'0````$`````````$(`````
M```4:````````!1H````````!2@````%````%0`````````(`````````!@`
M``!^`````0`````````&````````&9`````````9D`````````!`````````
M````````````!```````````````>0````$`````````!@```````!G0````
M````&=`````````'``````````````````````0`````````(````(0````!
M``````````8````````@T````````"#0````````1)``````````````````
M```0``````````````"*`````0`````````&````````96````````!E8```
M```````L````````````````````!```````````````D`````$`````````
M`@```````&60````````99````````!`R`````````````````````@`````
M`````````)@````!``````````(```````"F6````````*98`````````.P`
M```````````````````$``````````````"F`````0`````````"````````
MIT@```````"G2`````````;H````````````````````"```````````````
ML`````X``````````P```````+NP````````N[``````````"```````````
M``````````@`````````"````+P````/``````````,```````"[N```````
M`+NX``````````@````````````````````(``````````@```#(````!@``
M```````#````````N\````````"[P`````````(`````!@``````````````
M"``````````0````T0````$``````````P```````+W`````````O<``````
M```"0`````````````````````@`````````"````-8````!``````````,`
M``````#``````````,```````````(@````````````````````(````````
M``````#<````"``````````#````````P(@```````#`B``````````H````
M````````````````"```````````````X0````$`````````,```````````
M````````P(@`````````)0````````````````````$``````````0````$`
M```#`````````````````````````````,"M`````````.H`````````````
.```````!````````````
